@@ -37,7 +37,7 @@ KNSResource::KNSResource(const KNSCore::EntryInternal& entry, QStringList catego
 
 KNSResource::~KNSResource() = default;
 
-AbstractResource::State KNSResource::state()
+AbstractResource::State KNSResource::state() const
 {
     switch(m_entry.status()) {
         case KNS3::Entry::Invalid:
@@ -166,10 +166,12 @@ QString KNSResource::section()
 
 static void appendIfValid(QList<QUrl>& list, const QUrl &value, const QUrl &fallback = {})
 {
-    if (value.isValid() && !value.isEmpty())
-        list << value;
-    else if (!fallback.isEmpty())
-        appendIfValid(list, fallback);
+    if (list.contains(value)) {
+        if (value.isValid() && !value.isEmpty())
+            list << value;
+        else if (!fallback.isEmpty())
+            appendIfValid(list, fallback);
+    }
 }
 
 void KNSResource::fetchScreenshots()
