@@ -434,10 +434,23 @@ QVariant ResourcesProxyModel::roleToValue(AbstractResource* resource, int role)
     }
 }
 
+bool ResourcesProxyModel::isSorted(const QVector<AbstractResource*> & resources)
+{
+    auto last = resources.constFirst();
+    for(auto it = resources.constBegin()+1, itEnd = resources.constEnd(); it != itEnd; ++it) {
+        if(!lessThan(last, *it)) {
+            return false;
+        }
+        last = *it;
+    }
+    return true;
+}
+
 void ResourcesProxyModel::sortedInsertion(const QVector<AbstractResource*> & resources)
 {
     Q_ASSERT(!resources.isEmpty());
     if (m_sortByRelevancy || m_displayedResources.isEmpty()) {
+//         Q_ASSERT(m_sortByRelevancy || isSorted(resources));
         int rows = rowCount();
         beginInsertRows({}, rows, rows+resources.count()-1);
         m_displayedResources += resources;
@@ -450,12 +463,13 @@ void ResourcesProxyModel::sortedInsertion(const QVector<AbstractResource*> & res
         const auto it = std::upper_bound(m_displayedResources.constBegin(), m_displayedResources.constEnd(), resource, finder);
         const auto newIdx = it == m_displayedResources.constEnd() ? m_displayedResources.count() : (it - m_displayedResources.constBegin());
 
-        if (it != m_displayedResources.constEnd() && *it == resource)
+        if ((it-1) != m_displayedResources.constEnd() && *(it-1) == resource)
             continue;
 
         beginInsertRows({}, newIdx, newIdx);
         m_displayedResources.insert(newIdx, resource);
         endInsertRows();
+//         Q_ASSERT(isSorted(resources));
     }
 }
 
